All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 4/4] Dom0: extend fpu_ctxt to consist with Xen hypervisor
@ 2010-08-31  3:00 Han, Weidong
  2010-08-31  9:46 ` Christoph Egger
  0 siblings, 1 reply; 3+ messages in thread
From: Han, Weidong @ 2010-08-31  3:00 UTC (permalink / raw)
  To: Xen-devel; +Cc: jeremy@goop.org, Keir Fraser

[-- Attachment #1: Type: text/plain, Size: 148 bytes --]

fpu_ctxt must be consistent between Dom0 and Xen hypervisor. Otherwise, dom0 cannot boot up.

Signed-off-by: Weidong Han <weidong.han@intel.com>

[-- Attachment #2: Dom0-extend-fpu_ctxt.patch --]
[-- Type: application/octet-stream, Size: 1579 bytes --]

From a8db3ba7be721306d435e313049c29b7ba48fa3f Mon Sep 17 00:00:00 2001
From: Weidong Han <weidong.han@intel.com>
Date: Fri, 27 Aug 2010 10:14:16 -0400
Subject: [PATCH] Extend fpu_ctxt to consist with Xen hypervisor

fpu_ctxt must be consistent between Dom0 and Xen hypervisor.
Otherwise, dom0 cannot boot up.

Signed-off-by: Weidong Han <weidong.han@intel.com>
---
 arch/x86/include/asm/xen/interface.h |   11 ++++++++---
 1 files changed, 8 insertions(+), 3 deletions(-)

diff --git a/arch/x86/include/asm/xen/interface.h b/arch/x86/include/asm/xen/interface.h
index 9539998..5e18534 100644
--- a/arch/x86/include/asm/xen/interface.h
+++ b/arch/x86/include/asm/xen/interface.h
@@ -124,11 +124,16 @@ struct arch_shared_info {
 #ifndef __ASSEMBLY__
 /*
  * The following is all CPU context. Note that the fpu_ctxt block is filled
- * in by FXSAVE if the CPU has feature FXSR; otherwise FSAVE is used.
+ * in by XSAVE if the CPU has feature XSAVE, otherwise use FXSAVE if the CPU
+ * has feature FXSR; otherwise FSAVE is used.
  */
 struct vcpu_guest_context {
-    /* FPU registers come first so they can be aligned for FXSAVE/FXRSTOR. */
-    struct { char x[512]; } fpu_ctxt;       /* User-level FPU registers     */
+    /*
+     * FPU registers come first so they can be aligned for
+     * FXSAVE/FXRSTOR and XSAVE/XRSTOR. Using 4096 Bytes for
+     * future state extensions
+     */
+    struct { char x[4096]; } fpu_ctxt;       /* User-level FPU registers     */
 #define VGCF_I387_VALID (1<<0)
 #define VGCF_HVM_GUEST  (1<<1)
 #define VGCF_IN_KERNEL  (1<<2)
-- 
1.6.0.4


[-- Attachment #3: Type: text/plain, Size: 138 bytes --]

_______________________________________________
Xen-devel mailing list
Xen-devel@lists.xensource.com
http://lists.xensource.com/xen-devel

^ permalink raw reply related	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2010-08-31 12:54 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2010-08-31  3:00 [PATCH 4/4] Dom0: extend fpu_ctxt to consist with Xen hypervisor Han, Weidong
2010-08-31  9:46 ` Christoph Egger
2010-08-31 12:54   ` Weidong Han

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.